import picotts
import requests
import time

LANG = "fr-FR"

def say_weather(url, place, lang=LANG):
    req = requests.get(url, timeout=4, headers={})
    req.encoding = "utf-8"
    preindex = req.text.find('<pre>')
    epreindex = req.text.find('</pre>',preindex)
    text = req.text[preindex:epreindex].split('\n')
    inheader = False
    inregions = False
    inpredict = False
    forecast = ''

    if lang == "fr-FR":
        standardTimeZone = " HNA"
        daylightTimeZone = " HAA"
        forecasts = "pour le Nouveau-Brunswick"
        localforecast = "pour {}, Nouveau-Brunswick,"
        
    else:
        # assume english
        standardTimeZone = " AST"
        daylightTimeZone = " ADT"
        forecasts = "for New Brunswick"
        localforecast = "for {}, New Brunswick,"

    for i, line in enumerate(text):
        if i == 2: 
            inheader = True
        if (line == ""):
            if inheader:
                forecast = forecast.replace('\n', ' ').replace('  ', ' ')
                forecast = forecast.replace(forecasts, localforecast.format(place))
                picotts.say(forecast.replace(standardTimeZone, "").replace(daylightTimeZone, ""), lang=lang)
                inheader = False
                time.sleep(0.5)
                forecast = ''
                inregions = True
            elif inpredict:
                picotts.say(forecast.replace('..', ', ').replace('  ', ' '), lang=lang)
                inpredict = False
                break
            else:
                inregions = True 
        if inheader or (inpredict and not inregions):
            forecast += ' ' + line 
        elif inregions:
            if place in line:
                inpredict = True
            if '.' in line:
                inregions = False
                

def _main():

    # source https://meteo.gc.ca/forecast/public_bulletins_f.html

    weather_short_term_NB_fr = "https://meteo.gc.ca/forecast/public_bulletins_f.html?Bulletin=fpcn74.cwhx"
    weather_long_term_NB_fr = "https://meteo.gc.ca/forecast/public_bulletins_f.html?Bulletin=fpcn44.cwhx"
    
    weather_short_term_NB_en = "https://weather.gc.ca/forecast/public_bulletins_e.html?Bulletin=fpcn14.cwhx"
    weather_long_term_NB_en = "https://weather.gc.ca/forecast/public_bulletins_e.html?Bulletin=fpcn54.cwhx"

    import argparse

    parser = argparse.ArgumentParser(description='Test forecast script')
    parser.add_argument('-a', '--area', type=str, help='New Brunswick area (default "Moncton")')
    parser.add_argument('-L', '--lang', type=str, help='Language ("fr-FR", "en-US" or "en-GB", default "fr-FR")')
    parser.add_argument('-s', '--short', action="store_true", help='do not play short term forecast')
    parser.add_argument('-l', '--long', action="store_true", help='do not play long term forecast')
    
    args = parser.parse_args()

    #print("--area: ", args.area)
    #print("--lang: ", args.lang)
    #print("--short: ", args.short)
    #print("--long: ", args.long)
    
    if args.area:
        area = args.area
    else:
        area = 'Moncton'
        
    if args.lang:
        lang = args.lang
    else:
        lang = LANG
        
    if lang == 'fr-FR':
        short_term = weather_short_term_NB_fr
        long_term = weather_long_term_NB_fr 
    elif lang in ['en-US', 'en-GB']:
        short_term = weather_short_term_NB_en
        long_term = weather_long_term_NB_en
    else:
        print('Unknown language')
        return 
    
    picotts.say(" ", lang=lang)
    time.sleep(0.5)
    picotts.say(" ", lang=lang)
    time.sleep(0.25)
    
    if not args.short:
        say_weather(short_term, area, lang=lang)
    
    if not args.long:
        if not args.short: time.sleep(2)    
        say_weather(long_term, area, lang=lang)
        

if __name__ == '__main__':
    _main()

